@@ -29,6 +29,7 @@
 
 #include <KMainWindow>
 #include <KRandomSequence>
+#include <qimage.h>
 
 namespace Phonon
 {
@@ -77,6 +78,9 @@ class Kanagram : public KMainWindow
         /** hide the hint box and text. */
         void hideHint();
 
+        /** hide the picture hint*/
+        void hidePicHint();
+
         /** reset the input box in preparation for the next word entry */
         void resetInputBox();
 
@@ -113,6 +117,9 @@ class Kanagram : public KMainWindow
         /** show/hide the hint */
         void slotToggleHint();
 
+        /**show/hide the picture hint */
+        void slotTogglePicHint();///for picture hints
+
         /** slot to save non kcfg_ settings */
         void slotSaveSettings();
 
@@ -239,6 +246,7 @@ class Kanagram : public KMainWindow
         QRect m_quitRect;
         QRect m_revealRect;
         QRect m_hintRect;
+        QRect m_picHintRect;
         QRect m_upRect;
         QRect m_aboutKDERect;
         QRect m_aboutAppRect; 
@@ -255,7 +263,8 @@ class Kanagram : public KMainWindow
         bool m_overHelp; 
         bool m_overQuit; 
         bool m_overReveal; 
-        bool m_overHint; 
+        bool m_overHint;
+        bool m_overPicHint;
         bool m_overUp; 
         bool m_overAboutKDE; 
         bool m_overAboutApp; 
@@ -265,6 +274,8 @@ class Kanagram : public KMainWindow
         bool m_overHintBox;
 
         bool m_showHint;
+        bool m_showPicHint;
+        QImage m_pictureHint;
 
         /** colors for use in drawing text and lines */
         QColor m_fillColor; 
